@@ -11,6 +11,7 @@
 
 import _ from 'lodash';
 import * as utils from './utils';
+import * as c from './constants';
 
 const POINT_VALUE = 0;
 const POINT_TIMESTAMP = 1;
@@ -94,11 +95,15 @@ function groupBy(datapoints, interval, groupByCallback) {
   }));
 }
 
-function groupBy_perf(datapoints, interval, groupByCallback) {
+export function groupBy_perf(datapoints, interval, groupByCallback) {
   if (datapoints.length === 0) {
     return [];
   }
 
+  if (interval === c.RANGE_VARIABLE_VALUE) {
+    return groupByRange(datapoints, groupByCallback);
+  }
+
   let ms_interval = utils.parseInterval(interval);
   let grouped_series = [];
   let frame_values = [];
@@ -132,6 +137,19 @@ function groupBy_perf(datapoints, interval, groupByCallback) {
   return grouped_series;
 }
 
+export function groupByRange(datapoints, groupByCallback) {
+  const frame_values = [];
+  const frame_start = datapoints[0][POINT_TIMESTAMP];
+  const frame_end = datapoints[datapoints.length - 1][POINT_TIMESTAMP];
+  let point;
+  for (let i=0; i < datapoints.length; i++) {
+    point = datapoints[i];
+    frame_values.push(point[POINT_VALUE]);
+  }
+  const frame_value = groupByCallback(frame_values);
+  return [[frame_value, frame_start], [frame_value, frame_end]];
+}
+
 /**
  * Summarize set of time series into one.
  * @param {datapoints[]} timeseries array of time series
@@ -495,6 +513,7 @@ const exportedFunctions = {
   downsample,
   groupBy,
   groupBy_perf,
+  groupByRange,
   sumSeries,
   scale,
   offset,
